@@ -18,10 +18,11 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: ChmodJob.cc,v 1.1 1999/05/26 14:02:59 lav Exp $ */
+/* $Id: ChmodJob.cc,v 1.2 2000/01/22 16:27:28 lav Exp $ */
 
 #include <config.h>
 #include "ChmodJob.h"
+#include "url.h"
 
 ChmodJob::ChmodJob(FileAccess *s,int new_m,ArgV *a) : TreatFileJob(s,a)
 {
@@ -30,5 +31,11 @@ ChmodJob::ChmodJob(FileAccess *s,int new_m,ArgV *a) : TreatFileJob(s,a)
 
 void ChmodJob::TreatCurrent()
 {
-   session->Chmod(curr,m);
+   ParsedURL u(curr,true);
+   if(u.proto)
+      url_session=FA::New(&u);
+   if(url_session)
+      url_session->Chmod(u.path,m);
+   else
+      session->Chmod(curr,m);
 }
