@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: FileAccess.h,v 1.55 2000/10/12 08:23:22 lav Exp $ */
+/* $Id: FileAccess.h,v 1.57 2001/05/10 14:44:24 lav Exp $ */
 
 #ifndef FILEACCESS_H
 #define FILEACCESS_H
@@ -173,6 +173,7 @@ public:
    virtual const char *GetProto() = 0; // http, ftp, file etc
    bool SameProtoAs(FileAccess *fa) { return !strcmp(GetProto(),fa->GetProto()); }
    virtual FileAccess *Clone() = 0;
+   virtual const char *ProtocolSubstitution(const char *host) { return 0; }
 
    const char *GetVisualProto() { return vproto?vproto:GetProto(); }
    void SetVisualProto(const char *p) { xfree(vproto); vproto=xstrdup(p); }
@@ -480,6 +481,8 @@ public:
 
    // start with n==0, then increase n; returns 0 when no more
    static FileAccess *Walk(int *n,const char *proto);
+
+   static void ClearAll();
 };
 
 #endif /* FILEACCESS_H */
