@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: FileCopy.h,v 1.38 2000/07/28 17:02:25 lav Exp $ */
+/* $Id: FileCopy.h,v 1.39 2001/02/03 11:37:50 lav Exp $ */
 
 /*
   classes defined here:
@@ -83,7 +83,7 @@ public:
    virtual void WantDate() { want_date=true; date=NO_DATE_YET; }
    virtual void WantSize() { want_size=true; size=NO_SIZE_YET; }
    time_t GetDate() { return date; }
-   off_t  GetSize() { return size; }
+   off_t  GetSize() { if(size>=0 && pos>size) WantSize(); return size; }
 
    void SetDate(time_t d);
    void SetSize(off_t s);
