@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: ResMgr.h,v 1.20 2001/04/04 07:22:11 lav Exp $ */
+/* $Id: ResMgr.h,v 1.21 2001/05/15 15:23:52 lav Exp $ */
 
 #ifndef RESMGR_H
 #define RESMGR_H
@@ -75,9 +75,13 @@ public:
    static const char *SimpleQuery(const char *name,const char *closure);
    static ResValue Query(const char *name,const char *closure);
 
-   enum CmpRes { EXACT,SUBSTR,DIFFERENT };
+   enum CmpRes {
+      EXACT_PREFIX=0x00,SUBSTR_PREFIX=0x01,
+      EXACT_NAME  =0x00,SUBSTR_NAME  =0x10,
+      DIFFERENT=-1
+   };
 
-   static CmpRes VarNameCmp(const char *name1,const char *name2);
+   static int VarNameCmp(const char *name1,const char *name2);
    static const char *FindVar(const char *name,ResDecl **type);
    static const char *Set(const char *name,const char *closure,const char *value);
 
