@@ -1,7 +1,7 @@
 /*
  * lftp and utils
  *
- * Copyright (c) 1996-2000 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2001 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -63,6 +63,7 @@ public:
 
    virtual void Suspend();
    virtual void Resume();
+   bool IsSuspended() { return suspended; }
 
    virtual void Reconfig(const char *name=0) {};
    static void ReconfigAll(const char *name);
@@ -71,8 +72,11 @@ public:
 
    static void Delete(SMTask *);
    static int Roll(SMTask *);
+   static void DeleteAll();
 
    static SMTask *current;
+
+   static int TaskCount();
 };
 
 class SMTaskInit : public SMTask
