@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: Speedometer.cc,v 1.9 2000/08/26 19:11:25 lav Exp $ */
+/* $Id: Speedometer.cc,v 1.10 2000/12/18 10:03:56 lav Exp $ */
 
 #include <config.h>
 #include <math.h>
@@ -150,7 +150,7 @@ const char *Speedometer::GetETAStrFromTime(long eta)
 	       ueta--;
 	 }
       }
-      else if(eta>=MINUTE)
+      else if(eta>=100)
       {
 	 ueta=(eta+MINUTE/2)/MINUTE;
 	 letter=minute_c;
