@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: misc.cc,v 1.24 2001/02/13 10:07:31 lav Exp $ */
+/* $Id: misc.cc,v 1.25 2001/05/15 15:23:53 lav Exp $ */
 
 #include <config.h>
 #include "xmalloc.h"
@@ -33,6 +33,7 @@
 #ifdef TM_IN_SYS_TIME
 # include <sys/time.h>
 #endif
+#include <regex.h>
 #include "misc.h"
 #include "ProcWait.h"
 #include "SignalHook.h"
@@ -453,3 +454,16 @@ mktime_from_utc (struct tm *t)
   tb = mktime (gmtime (&tl));
   return (tl <= tb ? (tl + (tl - tb)) : (tl - (tb - tl)));
 }
+
+
+bool re_match(const char *line,const char *a,int flags)
+{
+   if(!a || !*a)
+      return false;
+   regex_t re;
+   if(regcomp(&re,a,REG_EXTENDED|REG_NOSUB|flags))
+      return false;
+   bool res=(0==regexec(&re,line,0,0,0));
+   regfree(&re);
+   return res;
+}
