@@ -1,8 +1,13 @@
 #ifdef WITH_MODULES
+# define MODULE_NETWORK	   1
 # define MODULE_PROTO_FTP  1
 # define MODULE_PROTO_HTTP 1
 # define MODULE_PROTO_FILE 1
 # define MODULE_PROTO_FISH 1
 # define MODULE_CMD_MIRROR 1
 # define MODULE_CMD_SLEEP  1
+CDECL_BEGIN
+extern const char *module_depend[];
+extern void module_init();
+CDECL_END
 #endif
