@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: resource.cc,v 1.53 2001/05/04 13:58:56 lav Exp $ */
+/* $Id: resource.cc,v 1.55 2001/05/24 10:18:47 lav Exp $ */
 
 #include <config.h>
 
@@ -176,6 +176,9 @@ static ResDecl
    ResDecl18 ("ftp:verify-address",	  "no",    ResMgr::BoolValidate,0),
    ResDecl19 ("ftp:verify-port",	  "no",    ResMgr::BoolValidate,0),
    ResDecl20 ("ftp:web-mode",		  "off",   ResMgr::BoolValidate,0),
+#define RETRY_530 "too many|overloaded|try (again |back )?later|is restricted to|maximum number|number of connect"
+   ResDecl20a("ftp:retry-530",		  RETRY_530,			ResMgr::ERegExpValidate,0),
+   ResDecl20b("ftp:retry-530-anonymous",  "Login incorrect|"RETRY_530,	ResMgr::ERegExpValidate,0),
    ResDecl21 ("hftp:cache",		  "yes",   ResMgr::BoolValidate,0),
    ResDecl22 ("hftp:proxy",		  "",	   HttpProxyValidate,0),
    ResDecl22a("hftp:use-authorization",	  "yes",   ResMgr::BoolValidate,0),
